async fn read_secret<P: AsRef<Path>>(path: P) -> Result<SigningKeyPassphrase>Expand description
Read a single passphrase from path via blocking std I/O.
async fn read_secret<P: AsRef<Path>>(path: P) -> Result<SigningKeyPassphrase>Read a single passphrase from path via blocking std I/O.